@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11945 2020-02-21 11:10:48Z Lavender $
+# $Id: views.py 11982 2020-03-19 11:39:46Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-21 20:10:48 +0900 (週五, 21 二月 2020) $
-# $Revision: 11945 $ 
+# $Date: 2020-03-19 20:39:46 +0900 (週四, 19 三月 2020) $
+# $Revision: 11982 $ 
 
 import json
 import logging
@@ -319,7 +319,7 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                 receive = 0 # 只先記錄 use 的部分
                       
             # record
-            record = BonusRecord.objects.create(
+            record = BonusRecord.objects.createBonusRecord(
                 user=user,
                 order=order,
                 use=use,
@@ -507,7 +507,7 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
         b.save()
         
         # record
-        record = BonusRecord.objects.create(
+        record = BonusRecord.objects.createBonusRecord(
             user=user,
             order=order,
             use=0, # 已在購買訂單時紀錄
@@ -601,6 +601,17 @@ Benefit = get_model('offer', 'Benefit')
 Range = get_model('offer', 'Range')
 Condition = get_model('offer', 'Condition')
 
+PageTitleMixin = get_class('customer.mixins', 'PageTitleMixin')
+
+class CustomerBonusListView(PageTitleMixin, generic.TemplateView):
+    template_name = 'shop/bonus/BonusList.html'
+    page_title = _('Bonus')
+    active_tab = 'bonus'
+    
+    def get_context_data(self, **kwargs):
+        ctx = super().get_context_data(**kwargs)
+        return ctx
+
 def useBonus(request):
     quantity = int(request.POST.get('quantity', 0))
     
@@ -722,7 +733,7 @@ def updateBonus(request, *args, **kwargs):
     b.save()
     
     # record
-    record = BonusRecord.objects.create(
+    record = BonusRecord.objects.createBonusRecord(
         user=user,
         order=None,
         adjust=adjust,
